@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use REST::Google::Search;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 sub guess_gender {
     my $opts;
@@ -80,13 +80,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Locale::ID::GuessGender::FromFirstName::google - google
 
 =head1 VERSION
 
-version 0.04
+This document describes version 0.05 of Locale::ID::GuessGender::FromFirstName::google (from Perl distribution Locale-ID-GuessGender-FromFirstName), released on 2014-05-26.
 
 =head1 FUNCTIONS
 
@@ -123,13 +125,29 @@ Google, for example.
 
 =back
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Locale-ID-GuessGender-FromFirstName>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Locale-ID-GuessGender-FromFirstName>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Locale-ID-GuessGender-FromFirstName>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
