@@ -3,7 +3,7 @@ package Locale::ID::GuessGender::FromFirstName::v1_rules;
 use strict;
 use warnings;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 # XXX extract from common list instead of wild guessing
 my @rules = (
@@ -68,13 +68,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Locale::ID::GuessGender::FromFirstName::v1_rules - v1_rules
 
 =head1 VERSION
 
-version 0.04
+This document describes version 0.05 of Locale::ID::GuessGender::FromFirstName::v1_rules (from Perl distribution Locale-ID-GuessGender-FromFirstName), released on 2014-05-26.
 
 =head1 FUNCTIONS
 
@@ -108,13 +110,29 @@ Whether the algorithm succeeds.
 
 =back
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Locale-ID-GuessGender-FromFirstName>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Locale-ID-GuessGender-FromFirstName>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Locale-ID-GuessGender-FromFirstName>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
